--[[
    MyRolePlay 4 (C) 2010-2022 Etarna Moonshyne <etarna@moonshyne.org>, Katorie, Meorawr
    Licensed under GNU General Public Licence version 2 or, at your option, any later version

    UI_Target.lua - Hook target functions & MSP receive handler to show/hide the MRP button
]]

function mrp:TargetChanged()
    if not mrpSaved.Options.Enabled or not mrpSaved.Options.ShowButton then
        MyRolePlayButton:Hide()
        return
    end
    if UnitIsUnit( "player", "target" ) then
        MyRolePlayButton:Show()
    elseif UnitIsPlayer( "target" ) then
        if msp.char[ mrp:UnitNameWithRealm( "target" ) ].supported then
            MyRolePlayButton:Show()
        else
            MyRolePlayButton:Hide()
        end
    else
        MyRolePlayButton:Hide()
    end
end

local function mrp_TargetEvent( this, event, addon )
    if event == "PLAYER_TARGET_CHANGED" or event == "PLAYER_ENTERING_WORLD" then
        mrp:TargetChanged()
		mrp:ShowHideGlancePreview()
    end
end

function mrp_MSPButtonCallback( player )
    if UnitIsPlayer( "target" ) and mrp:UnitNameWithRealm( "target" ) == player then
        MyRolePlayButton:Show()
    end
end

local df = CreateFrame("Frame")
df:SetScript( "OnEvent", mrp_TargetEvent )

function mrp:HookTarget()
    df:RegisterEvent( "PLAYER_TARGET_CHANGED" )
	df:RegisterEvent( "PLAYER_ENTERING_WORLD" ) -- Patch 9.1 - resolves issue with the MRP button persisting through loading screens by rechecking target status.
end

function mrp:UnhookTarget()
    df:UnregisterEvent( "PLAYER_TARGET_CHANGED" )
end
